@@ -72,6 +72,9 @@ READ_SPATIAL_BARCODE1_POS_TAG = "XP"
 READ_SPATIAL_BARCODE2_TAG = "X2"
 READ_SPATIAL_BARCODE2_POS_TAG = "XQ"
 
+READ_DEMUX_TAG = "id"
+READ_DEMUX_POS_TAG = "ip"
+
 READ_BGZF_VIRTUAL_OFFSET_TAG = "vo"
 
 COULD_CORRECT_BARCODE_TAG = "YC"  # True IFF barcode correction was able to be performed (including "correction" where the original barcode did not change).  False otherwise.
